elephant.spike\_train\_correlation.spike\_time\_tiling\_coefficient
===================================================================

.. currentmodule:: elephant.spike_train_correlation

.. autofunction:: spike_time_tiling_coefficient